# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

Name:           xslthl
Version:        2.0.2
Release:	1%{?dist}
Epoch:          0
Summary:        XSLT Syntax Highlighting
License:        zlib/libpng
URL:            http://sourceforge.net/projects/xslthl
Group:          Development/Tools
# svn -q export https://xslthl.svn.sourceforge.net/svnroot/tags/v2_0_2 xslthl-2.0.2 && tar cjf xslthl-2.0.2.tar.bz2 xslthl-2.0.2
Source0:        xslthl-2.0.2.tar.bz2
Source1:        https://oss.sonatype.org/content/groups/public/net/sf/xslthl/xslthl/2.0.2/xslthl-2.0.2.pom
Patch0:         xslthl-build.patch
Requires(post): jpackage-utils >= 0:1.7.3
Requires(postun): jpackage-utils >= 0:1.7.3
BuildRequires:  ant >= 0:1.6.5
BuildRequires:  java-devel >= 0:1.5.0
BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  saxon
BuildRequires:  saxon9
BuildRequires:  xalan-j2
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
Buildarch:     noarch
%endif
Buildroot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
This is an implementation of syntax highlighting as an 
extension module for XSLT processors, so if you have e.g. 
article about programming written in DocBook, code examples
can be automatically syntax highlighted during the XSLT 
processing phase.

%package javadoc
Group:          Documentation
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%prep
%setup -q 
%{_bindir}/find . -name "*.jar" | %{_bindir}/xargs -t rm
%patch0 -p0 -b .sav0

%build
export CLASSPATH=$(build-classpath saxon saxon9 xalan-j2)
export OPT_JAR_LIST=:
%{ant} -Dbuild.sysclasspath=only
%{ant} -Dbuild.sysclasspath=only javadoc

%install
rm -rf %{buildroot}

# jars
install -d -m 755 %{buildroot}%{_javadir}
install -p -m 644 dist/xslthl-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar

(cd %{buildroot}%{_javadir}
for jar in *-%{version}*; do ln -s ${jar} `/bin/echo ${jar} | sed  "s|-%{version}||g"`; done
)

# pom
install -d -m 755 %{buildroot}%{_datadir}/maven2/poms
install -p -m 644 %{SOURCE1} %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap net.sf.xslthl xslthl %{version} JPP %{name}

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}-%{version}
cp -pr build/javadoc/* %{buildroot}%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif 

%clean
rm -rf %{buildroot}

%post
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif
%update_maven_depmap

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-%{version}.jar.*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%changelog
* Thu Sep 16 2010 David Walluck <dwalluck@redhat.com> 0:2.0.2-1
- 2.0.2

* Mon Dec 08 2008 Will Tatam <will.tatam@red61.com> 1.3-2
- Auto rebuild for JPackage 5 in mock

* Mon Feb 25 2008 Ralph Apel <r.apel@r-apel.de> - 0:1.3-1jpp
- 1.3

